package components.baseComponents
{
	import values.Constants;
	

	import mx.controls.DateField;

	/** Cette classe assouplit l'utilisation de la classe standard "DateField".
	 *  Certaines propriétés du composant sont fixées en dure.
	 */

	public class ExtendedDateField extends DateField
	{
		private var __rangeStart:Date             = null;
		private var __rangeEnd:Date               = null;
		
		public function ExtendedDateField()
		{
			super();
			this.editable = false;
		}

		/** Cette méthode définit le début de la plage autorisée de sélection d'une date.
		 *  @param inDate Date de début de la plage de sélection.
		 *  @remark La classe standard définit un interval dans lequel la sélection est impossible.
		 *          La logique est inversée par rapport à la logique de la classe de base.
		 */
		
		public function enableRangeStart(inDate:Date):void
		{
			// trace ('enableRangeStart(' + inDate.toString() + ')');
			__rangeEnd = new Date(inDate.time - values.Constants.millisecondsPerDay);
			this.disabledRanges = [{rangeEnd: __rangeEnd}];
			if (__rangeStart != null) { this.disabledRanges.push({rangeStart: __rangeStart}); }
		}

		/** Cette méthode définit la fin de la plage autorisée de sélection d'une date.
		 *  @param inDate Date de fin de la plage de sélection.
		 *  @remark La classe standard définit un interval dans lequel la sélection est impossible.
		 *          La logique est inversée par rapport à la logique de la classe de base.
		 */	
		
		public function enableRangeEnd(inDate:Date):void
		{
			// trace ('enableRangeEnd(' + inDate.toString() + ')');
			__rangeStart = new Date(inDate.time + values.Constants.millisecondsPerDay);
			this.disabledRanges = [{rangeStart: __rangeStart}];
			if (__rangeEnd != null) { this.disabledRanges.push({rangeEnd: __rangeEnd}); }
		}
	}
}