package components.baseComponents
{
	import evenements.Action;
	
	import flash.events.Event;
	
	import interfaces.IActorInterface;
	import interfaces.ICompositeActorInterface;
	import interfaces.IGhostInterface;
	import interfaces.ISelectorInterface;
	
	import mx.controls.TextArea;
	import mx.events.FlexEvent;
	
	import tools.FunctionUtilities;

	/**
	 * Cette classe permet de créer une zone d'édition simple, sur plusieurs ligne.
	 * Cette classe est susceptible de lancer deux types d'action :
	 *  o DataSetted
	 *  o TextChanged
	 */

	public class ExtendedTextArea extends TextArea implements IActorInterface, ICompositeActorInterface, IGhostInterface, ISelectorInterface
	{
		private var __onModifHd:Function = tools.FunctionUtilities.doNothing; 
		private var __myName:String;
		
		public function ExtendedTextArea()
		{
			super();
			this.addEventListener(flash.events.Event.CHANGE,        __textChanged);
			this.addEventListener(mx.events.FlexEvent.VALUE_COMMIT, __textChanged);
		}
		
		/** Cette méthode permet de nommer le composant. Le nom est utilisé pour désigner l'émetteur d'un évènement de changement d'état fonctionnel.
		 *  @param inName Nom du composant. 
		 */
		
		public function setName(inName:String):void
		{
			__myName = inName;
		}
		
		/** Cette méthode permet de définir une fonction, qui sera exécutée par l'acteur, à chaque fois que ce dernier change d'état.
		 *  @param inFunction Fonction exécutée par le composant à chaque fois que ce dernier change d'état.
		 *  @note Prototype de la fonction: inFunction(inData:Object=null):void
		 */
		
		public function setOnModificationHandler(inFunction:Function=null):void
		{
			if (inFunction != null) { __onModifHd = inFunction }
		}
		
		/** Cette méthode rend le composant éligible à la destruction.
		 */
		
		public function destroy():void
		{
			this.removeEventListener(flash.events.Event.CHANGE,        __textChanged);
			this.removeEventListener(mx.events.FlexEvent.VALUE_COMMIT, __textChanged);
		}
		
		/** Cette méthode retourne un objet qui contient le texte entré par l'utilisateur.
		 *  @return La méthode renvoie un objet qui présente la propriété "text". Cette propriété représente le texte entré par l'utilisateur.
		 */ 
		
		public function getSelectedValues():Object
		{
			return { text:this.text };
		}
		
		/** Cette méthode permet d'initialiser le composant avec un texte donné.
		 *  @param inValues Cet objet présente la propriété "text" qui représente le texte à injecter dans la zone d'édition.
		 *  @param inDispatchEvt Si ce paramètre vaut "true", alors un évènement est envoyé pour signaler que ma valeur a été initialisée.
		 */
		
		public function setValues(inValues:Object, inDispatchEvt:Boolean=true):void
		{
			this.text = inValues.text;
			if (inDispatchEvt) { dispatchEvent(new Action('Action', __myName, "DataSetted", true)); }
		}
		
		/** Cette méthode rend le composant utilisable par l'utilisateur.
		 */
		
		public function enable():void
		{
			this.enabled = true;
		}

		/** Cette méthode rend le composant inutilisable par l'utilisateur.
		 */
		
		public function disable():void
		{
			this.enabled = false;
		}
		
		/** Cette méthode permet de réinitialiser le contenu de la zone d'édition.
		 * 	En fonction de la valeur du paramètre "inValues", la zone est "vidée" ou elle se voit attribuer une valeur.
		 *  @param inValues Cet objet doit présenter la propriété "text" qui représente le texte à injecter dans la zone d'édition.
		 */
		
		public function reset(inValues:Object=null):void
		{
			if (inValues == null) { this.text = ''; return; }
			this.text = inValues.text;
		}
		
		/** Ce gestionnaire d'évènement est exécuté lorsque le contenu de la zone d'édition change.
		 *  @param event Évènement envoyé lorsque le contenu de la zone d'édition change.
		 */
		
		private function __textChanged(event:Event):void
		{
			trace ('ExtendedTextArea + __textChanged()');
			__onModifHd(getSelectedValues());
			dispatchEvent(new Action('Action', __myName, "TextChanged", true));
		}
		
	}
}