package components.baseComponents
{
	import components.popups.WaitBox;
	
	import flash.events.Event;
	import flash.events.IOErrorEvent;
	import flash.net.FileReference;
	import flash.net.URLRequest;
	
	import gestionnaires.EventHandlerControler;
	
	import interfaces.IActorInterface;
	import interfaces.ICompositeActorInterface;
	import interfaces.IGhostInterface;
	import interfaces.ISelectorInterface;
	
	import mx.containers.HBox;
	import mx.controls.Button;
	import mx.controls.Text;
	import mx.core.IFlexDisplayObject;
	import mx.events.FlexEvent;
	import mx.managers.PopUpManager;
	
	import tools.FunctionUtilities;

	/**
	 * Cette classe est destinée à faciliter le transfert de fichiers entre une application Flex et un serveur PHP.
	 */

	public class FileUploader extends HBox implements IGhostInterface, IActorInterface, ICompositeActorInterface, ISelectorInterface
	{
		private var __uploadUrl:String;
		private var __varName:String;
		private var __extensions:Array;
		private var __myName:String;
		private var __browseButtonLabel:String;
		private var __browseButton:Button;
		private var __pathScreen:Text;
		private var __browser:FileReference;
		private var __fileName:String;
		private var __popup:IFlexDisplayObject;
		private var __evtHd:EventHandlerControler = new EventHandlerControler();
		private var __onModifHd:Function = tools.FunctionUtilities.doNothing;

		
		/** Ce constructeur construit un composant de transfert de fichier.
		 *  @param inUploadUrl URL du scripte vers lequel le fichier doit être transféré.
		 *  @param inVarName Nom de la variable associée au fichier reçu par le serveur WEB.
		 *  @param inFileTypes Liste des extensions de fichiers supportées. Cette liste est composée d'éléments de type FileFilter.
		 *  @param inBrowseButtonLabel Texte à afficher sur le bouton qui va ouvrir la fenêtre d'exploration de l'arborescence.
		 */
		
		public function FileUploader(inUploadUrl:String, inVarName:String, inFileTypes:Array=null, inBrowseButtonLabel:String='Browse')
		{
			super();
			__uploadUrl = inUploadUrl;
			__varName = inVarName;
			__extensions = inFileTypes;
			__browseButtonLabel = inBrowseButtonLabel;
			__browser = new FileReference();
			__createInterface();
			__setEventHandler();
		}
		
		/** Cette méthode construit l'interface utilisateur.
		 */
		
		private function __createInterface():void
		{
			__browseButton = new Button();
			__browseButton.label = __browseButtonLabel;
			
			__pathScreen = new Text();
			__pathScreen.width = 200;
			__pathScreen.setStyle('fontWeight', 'bold');
			
			this.addChild(__pathScreen);
			this.addChild(__browseButton);
			 
		}
		
		/** Cette méthode est utilisée pour déclarer les évènements traités par cette classe.
		 */		
		
		private function __setEventHandler():void
		{
			__evtHd.addEventHandler(__browseButton, mx.events.FlexEvent.BUTTON_DOWN, __browse);
			__evtHd.addEventHandler(__browser, flash.events.Event.SELECT, __fileSelected);
			__evtHd.addEventHandler(__browser, flash.events.Event.COMPLETE, __uploadComplete);
			__evtHd.addEventHandler(__browser, flash.events.IOErrorEvent.IO_ERROR, __uploadFailed);
		}
		
		/** Cette méthode rend le composant éligible à la destruction.
		 */
		
		public function destroy():void
		{
			__evtHd.removeAllEventHandlers();
		}
		
		/** Cette méthode permet de nommer le composant. Le nom est utilisé pour désigner l'émetteur d'un évènement de changement d'état fonctionnel.
		 *  @param inName Nom du composant. 
		 */
		
		public function setName(inName:String):void
		{
			__myName = inName;
		}
		
		/** Cette méthode permet de définir une fonction, qui sera exécutée, qu'un nouveau fichier sera sélectionné.
		 *  @param inFunction Fonction exécutée par le composant à chaque fois que ce dernier change d'état.
		 *  @note Prototype de la fonction: inFunction(inData:Object=null):void
		 */
		
		public function setOnModificationHandler(inFunction:Function=null):void
		{
			__onModifHd = inFunction;
		}
		
		/** Cette méthode renvoie le nom du fichier sélectionnée par l'utilisateur.
		 *  @return Cette méthode renvoie un objet. Cet objet contient une clé "name", associé au nom du fichier.
		 */
		
		public function getSelectedValues():Object
		{
			return { name: __fileName };
		}
		
		/** Cette méthode rend le composant utilisable par l'utilisateur.
		 */
		
		public function enable():void
		{
			__browseButton.enabled = true;	
		}
		
		/** Cette méthode rend le composant inutilisable par l'utilisateur.
		 */
		
		public function disable():void
		{
			__browseButton.enabled = false;
		}

		// ---------------------------------------------------------------------------------
		// Gestionnaires d'évènements.
		// ---------------------------------------------------------------------------------

		/** Ce gestionnaire d'évènement est exécuté lorsque l'utilisateur presse le bouton de sélection du fichier à transférer.
		 *  @param event Évènement envoyé lorsque le bouton de sélection du fichier est pressé.
		 */
		
		private function __browse(event:Event):void
		{
			__browser.browse(__extensions);
		}
		
		/** Ce gestionnaire d'évènement est exécuté lorsque l'utilisateur sélectionne un fichier.
		 *  @param event Évènement envoyé lorsque l'utilisateur sélectionne un fichier.
		 */
		
		private function __fileSelected(event:Event):void
		{
			var url:URLRequest;
			
			__fileName = __browser.name;
			if (__fileName == null) { return; }
			__pathScreen.text = __fileName;
			
			// On exécute la fonction qui doit être exécutée à chaque modification du nom du fichier sélectionné.
			__onModifHd(getSelectedValues());
			
			// On active la boîte modale qui représente l'attente.
			url = new URLRequest(__uploadUrl);
			__popup = PopUpManager.createPopUp(this.parent, components.popups.WaitBox, true);
			PopUpManager.centerPopUp(__popup);
			__browser.upload(url, __varName);
		}

		/** Ce gestionnaire d'évènement est exécuté lorsque le fichier est totalement transféré sur le serveur.
		 *  @param event Cet évènement est envoyé lorsque le fichier est totalement transféré sur le serveur.
		 */

		private function __uploadComplete(event:Event):void
		{
			PopUpManager.removePopUp(__popup);
		}
		
		/** Cegestionnaire d'évènement est exécuté si une erreur se produit lors du transfert du fichier vers le serveur.
		 *  @param Cet évènement est envoyé si une erreur se produit lors du transfert du fichier vers le serveur. 
		 */
		
		private function __uploadFailed(event:Event):void
		{
			var popup:IFlexDisplayObject;
			
			PopUpManager.removePopUp(__popup);
			popup = PopUpManager.createPopUp(this.parent, components.popups.ServerError, true);
			PopUpManager.centerPopUp(popup);
		}

		// ---------------------------------------------------------------------------------
		// Fonctions non implémentées.
		// ---------------------------------------------------------------------------------
		
		/** Dans le cas particulier de ce composant, cette fonction n'est pas utilisable.
		 *  @param inValues NA.
		 *  @note Cette méthode est définie uniquement pour implémenter l'interface ISelectorInterface.
		 */
		
		public function reset(inValues:Object=null):void { }

		/** Dans le cas particulier de ce composant, cette fonction n'est pas utilisable.
		 *  @param inValues NA.
		 *  @param inDisparchEvt NA.
		 *  @note Cette méthode est définie uniquement pour implémenter l'interface ISelectorInterface.
		 */

		public function setValues(inValues:Object, inDispatchEvt:Boolean=true):void { }
	}
}