package evenements
{
	import flash.events.Event;

	/** Cette classe représente un évènement "fonctionnel".
	 *  Ce type d'évènement n'a de sens que du point de vue de l'application.
	 *  Cet évènement se caractérise par deux propriétés :
	 *  o La source: L'élément fonctionnel qui désire signaler un changement d'état.
	 *  o Une action: Un changement d'état, qui n'a de sens que du point de vue fonctionnel.
	 */

	public class Action extends Event
	{
		private var __booleanBubbles:Boolean;
		private var __booleanCancelable:Boolean;
		private var __source:String;
		private var __action:String;
		private var __stringType:String;

		/** Ce constructeur crée un évènement fonctionnel.
		 *  @param source Nom de l'élément fonctionnel qui désire signaler un changement d'état.
		 *  @param action Nom du changement d'état. 
		 */
		
		public function Action(type:String, source:String, action:String, bubbles:Boolean=false, cancelable:Boolean=false)
		{
			super(type, bubbles, cancelable);
			__stringType        = type;
			__booleanBubbles    = bubbles;
			__booleanCancelable = cancelable;
			__source            = source;
			__action            = action;
		}

		override public function clone():Event
		{
			return new Action(__stringType, __source, __action, __booleanBubbles, __booleanCancelable);
		}

		/** Retourne le nom de l'élément fonctionnel à l'origine de l'action.
		 *  @return La méthode retourne le nom de l'élément fonctionnel à l'origine de l'action.
		 */
		
		public function getSource():String { return __source; }
		
		/** Retourne le nom du changement d'état à signaler.
		 *  @return La méthode retourne le nom du changement d'état à signaler.
		 */
		
		public function getAction():String { return __action; }
	}
}