package gestionnaires
{
	import interfaces.IActorInterface;
	
	/** Cette classe permet de gérer des "acteurs".
	 *  Les "acteurs" sont des composants, identifiés par leur nom, qui signalent certains changements d'état fonctionnel en envoyant des évènements.
	 */
	
	public class Actor
	{
		static private var __actors:Object = new Object();
		
		public function Actor() { }

		/** Cette classe permet de gérer des "acteurs".
		 *  @param inName Nom de l'acteur.
		 *  @param actor Objet qui représente l'acteur.
		 */

		public function register(inName:String, actor:IActorInterface):void
		{
			if (__actors.hasOwnProperty(inName)) { throw new Error("Duplicated actor " + inName); }
			__actors[inName] = actor;
			actor.setName(inName);
		}

		/** Retourne un acteur identifié par son nom.
		 *  @param inName Nom de l'acteur.
		 *  @return La méthode retourne un objet de type "Actor".
		 */
		
		public function getActor(inName:String):IActorInterface
		{
			if (! __actors.hasOwnProperty(inName)) { throw new Error("Unknown actor " + inName); }
			return __actors[inName];
		}
	}
}