package gestionnaires
{
	import flash.events.EventDispatcher;
	import flash.utils.Dictionary;
	import flash.utils.getQualifiedClassName;
	
	/** Cette classe gère les attributions et les retraits de gestionnaires d'évènement.
	 */
	
	public class EventHandlerControler
	{
		private var __handlers:Dictionary = new Dictionary();

		/** Ajoute un gestionnaire d'évènement.
		 * 
		 * @param display Composant sur lequel est ajouté le gestionnaire d'évènement.
		 * @param id Chaîne de caractère utilisée pour identifier le composant.
		 * @param event Type d'évènement à intercepter.
		 * @param handler Référence sur le gestionnaire d'évènement à exécuter sur réception de l'évènement.
		 */

		public function addEventHandler(display:EventDispatcher, event:String, handler:Function):void
		{
			// Ajout d'un gestionnaire à l'objet qui doit le recevoir.
			display.addEventListener(event, handler);
			if (__handlers[display] == null) { /* trace ("New Object()") */; __handlers[display] = new Object(); }
			__handlers[display][event] = handler;
			// trace ("Event " + event + " added");
		}
	
		/** Retire un gestionnaire d'évènement.
		 * 
		 * @param display Composant sur lequel est retiré le gestionnaire d'évènement.
		 * @param event Type d'évènement intercepté.
		 */
		
		public function removeEventHandler(display:EventDispatcher, event:String):void
		{
			var handler:Function;
						
			if (__handlers[display] == null)                { throw new Error("Attempt to remove an event handler on an unclassified object."); }
			if (!__handlers[display].hasOwnProperty(event)) { throw new Error("The object you specified does not listen to the event " + event + '.'); }
			handler = __handlers[display][event];
			display.removeEventListener(event, handler);
			delete __handlers[display][event];
		}
		
		/** Retire tous les gestionnaires d'évènement associés.
		 */
		
		public function removeAllEventHandlers():void
		{
			var handler:Function;
			
			// trace ("removeAllEventHandlers()");
			for (var display:Object in __handlers)
			{
				// trace (flash.utils.getQualifiedClassName(display));
				for (var event:String in __handlers[display])
				{
					// trace ("  => " + event);
					handler = __handlers[display][event];
					display.removeEventListener(event, handler);
					delete __handlers[display][event];
					// trace ("Removing event " + event + " on " + flash.utils.getQualifiedClassName(display));
				}
				display = null;
				delete __handlers[display];
			}
		}
	}
}