package interfaces
{
	
	/** Cette interface définit un type de composant qui présente la particularité d'autoriser la sélection de plusieurs valeurs.
	 *  Par exemple : Un composant de type GeoPicker permet de sélectionner 3 valeurs :
	 *                o Région.
	 *                o Région + Département.
	 *                o Région + Département + Code postal.
	 *  Suivant le contexte (logique d'utilisation) dans lequel est utilisé ce composant, les critères d'interprétation des valeurs sélectionnées ne sont pas les mêmes.
	 *  Par exemple : Lorsque les trois valeurs géographiques (région, département, code postal) sont sélectionnées simultanément, cela signifie quelque chose de particulier pour vous.
	 *                Dans un autre contexte d'utilisation, la simultanéité de la sélection ne vous intéresse pas.
	 * 
	 *  Cette interface définit un ensemble de méthode qui permette d'injecter, dans le composant, du "code étranger" (correspondant à de la logique d'utilisation spécifique).
	 */
	
	public interface ICompositeActorInterface
	{
		/** Cette méthode permet de définir une fonction, qui sera exécutée par l'acteur, à chaque fois que ce dernier change d'état.
		 *  @param inFunction Fonction exécutée par le composant à chaque fois que ce dernier change d'état.
		 *  @note Prototype de la fonction: inFunction(inData:Object=null):void
		 */
		
		function setOnModificationHandler(inFunction:Function=null):void;		
	}
}