package interfaces
{
	/** Cette interface définit les composants de type "Selector".
	 *  Ce type de composant est utilisé pour sélectionner des valeurs.
	 *  Il peut aussi être initialisé à des valeurs de départ.
	 */
	
	public interface ISelectorInterface
	{
		/** Cette méthode renvoie les valeurs sélectionnées par l'utilisateur.
		 *  L'organisation de l'objet renvoyé dépend de la nature des informations sélectionnées.
		 */
		
		function getSelectedValues():Object;
		
		/** Cette méthode permet d'initialiser un composant de sélection avec des valeurs.
		 *  @param inValues Cet objet contient les valeurs utilisées pour l'initialisation du composant.
		 *  @param inDisparchEvt Cet argument permet de spécifier si le composant doit envoyer un évènement suite à la mise à jour de l'heure.
		 */
		
		function setValues(inValues:Object, inDispatchEvt:Boolean=true):void;
		
		/** Cette méthode rend le composant utilisable par l'utilisateur.
		 */
		
		function enable():void;

		/** Cette méthode rend le composant inutilisable par l'utilisateur.
		 */
		
		function disable():void;

		/** Cette méthode réinitialise le composant.
		 *  @param inValues Cet objet spécifie la liste des valeurs à réinitialiser.
		 *         Chaque propriété de l'objet représente une propriété à réinitialiser.
		 */
		
		function reset(inValues:Object=null):void;
	}
}